@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::DBR;
 {
-  $Dist::Zilla::PluginBundle::DBR::VERSION = '0.002';
+  $Dist::Zilla::PluginBundle::DBR::VERSION = '0.020';
 }
 BEGIN {
   $Dist::Zilla::PluginBundle::DBR::AUTHORITY = 'cpan:DBR';
@@ -24,22 +24,16 @@ class Dist::Zilla::PluginBundle::DBR with Dist::Zilla::Role::PluginBundle::Easy
         );
 
         $self->add_plugins(
-            'AutoPrereqs',
+            'ConfirmRelease',
+            'EOLTests',
             'MetaJSON',
             'ModuleBuild',
-            'PodWeaver',
-            'ReadmeFromPod',
-            'Test::Compile',
-            'AutoPrereqs',
+            'NoTabsTests',
             'PkgVersion',
             'PodCoverageTests',
             'PodSyntaxTests',
-            'NoTabsTests',
-            'EOLTests',
-            'Test::Compile',
+            'ReadmeFromPod',
             'TestRelease',
-            'ConfirmRelease',
-            'PodWeaver',
         );
     }
 }
@@ -54,7 +48,7 @@ Dist::Zilla::PluginBundle::DBR - DBRs Dist::Zilla PluginBundle
 
 =head1 VERSION
 
-version 0.002
+version 0.020
 
 =head1 SYNOPSIS
 
